schema.experimental.abstract-map

Schemas representing abstract classes and subclasses

Schemas representing abstract classes and subclasses
raw docstring

schema.experimental.complete

Deprecated---please migrate to https://github.com/plumatic/schema-generators

(Extremely) experimental support for 'completing' partial datums to match a schema. To use it, you must provide your own test.check dependency.

Deprecated---please migrate to https://github.com/plumatic/schema-generators

(Extremely) experimental support for 'completing' partial datums to match
a schema. To use it, you must provide your own test.check dependency.
raw docstring

schema.experimental.generators

Deprecated---please migrate to https://github.com/plumatic/schema-generators

(Very) experimental support for compiling schemas to test.check generators. To use it, you must provide your own test.check dependency.

TODO: add cljs support.

Deprecated---please migrate to https://github.com/plumatic/schema-generators

(Very) experimental support for compiling schemas to test.check generators.
To use it, you must provide your own test.check dependency.

TODO: add cljs support.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries