schema.spec.collection

A collection spec represents a collection of elements, each of which is itself schematized.

A collection spec represents a collection of elements,
each of which is itself schematized.
raw docstring

schema.spec.core

Protocol and preliminaries for Schema 'specs', which are a common language for schemas to use to express their structure.

Protocol and preliminaries for Schema 'specs', which are a common language
for schemas to use to express their structure.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries