Utilities for testing with schemas
Utilities for testing with schemas
(deftest name & body)A test with schema validation turned on globally during execution of the body.
A test with schema validation turned on globally during execution of the body.
(validate-schemas fn-test)A fixture for tests: put (use-fixtures :once schema.test/validate-schemas) in your test file to turn on schema validation globally during all test executions.
A fixture for tests: put (use-fixtures :once schema.test/validate-schemas) in your test file to turn on schema validation globally during all test executions.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |