A collection spec represents a collection of elements, each of which is itself schematized.
A collection spec represents a collection of elements, each of which is itself schematized.
Protocol and preliminaries for Schema 'specs', which are a common language for schemas to use to express their structure.
Protocol and preliminaries for Schema 'specs', which are a common language for schemas to use to express their structure.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |